@@ -35,8 +35,7 @@ class ORM(object):
         if sql_flavor not in self.sql_types:
             raise ValueError("Unknown SQL flavor")
         self.sql_flavor = sql_flavor
-        self.connection = connector
-        self.cursor = self.connection.cursor()
+        self.cursor = connector.cursor() if hasattr(connector, 'cursor') else connector
         self._obranch = obranch
         self._orev = orev
 
